==> qbs-1.2.1.src.zip: qbs-1.2.1/src/lib/corelib/language/asttools.cpp <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the Qt Build Suite.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "asttools.h"
#include <parser/qmljsast_p.h>

namespace qbs {
namespace Internal {

QStringList toStringList(QbsQmlJS::AST::UiQualifiedId *qid)
{
    QStringList result;
    for (; qid; qid = qid->next)
        result.append(qid->name.toString());
    return result;
}

CodeLocation toCodeLocation(const QString &filePath, QbsQmlJS::AST::SourceLocation location)
{
    return CodeLocation(filePath, location.startLine, location.startColumn);
}

QString textOf(const QString &source, QbsQmlJS::AST::Node *node)
{
    if (!node)
        return QString();
    return source.mid(node->firstSourceLocation().begin(),
                      node->lastSourceLocation().end() - node->firstSourceLocation().begin());
}

QStringRef textRefOf(const QString &source, QbsQmlJS::AST::Node *node)
{
    const quint32 firstBegin = node->firstSourceLocation().begin();
    return source.midRef(firstBegin, node->lastSourceLocation().end() - firstBegin);
}

} // namespace Internal
} // namespace qbs

==> qbs-1.3.3.src.zip: qbs-1.3.3/src/lib/corelib/language/asttools.cpp <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the Qt Build Suite.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "asttools.h"
#include <parser/qmljsast_p.h>

namespace qbs {
namespace Internal {

QStringList toStringList(QbsQmlJS::AST::UiQualifiedId *qid)
{
    QStringList result;
    for (; qid; qid = qid->next)
        result.append(qid->name.toString());
    return result;
}

CodeLocation toCodeLocation(const QString &filePath, const QbsQmlJS::AST::SourceLocation &location)
{
    return CodeLocation(filePath, location.startLine, location.startColumn);
}

QString textOf(const QString &source, QbsQmlJS::AST::Node *node)
{
    if (!node)
        return QString();
    return source.mid(node->firstSourceLocation().begin(),
                      node->lastSourceLocation().end() - node->firstSourceLocation().begin());
}

QStringRef textRefOf(const QString &source, QbsQmlJS::AST::Node *node)
{
    const quint32 firstBegin = node->firstSourceLocation().begin();
    return source.midRef(firstBegin, node->lastSourceLocation().end() - firstBegin);
}

} // namespace Internal
} // namespace qbs
